@@ -4,7 +4,7 @@ from openfisca_tools.microsimulation import (
 )
 from openfisca_tools.hypothetical import IndividualSim
 from openfisca_tools.testing import generate_tests
-from openfisca_tools.model_api import *
+from openfisca_tools.model_api.model_api import *
 from openfisca_tools.reforms import (
     restructure,
     new_variable,
